This crate provides integration between the shaku and axum crates.
See Inject and InjectProvided for details.
Structs
- Inject
- Used to retrieve a reference to a component from a shaku
Module. The module should be stored in Axum state, wrapped in anArc(Arc<MyModule>). ThisArc<MyModule>must implementFromRef<S>whereSis the Axum state type. - Inject
Provided - Used to create a provided service from a shaku
Module. The module should be stored in Axum state, wrapped in anArc(Arc<MyModule>). ThisArc<MyModule>must implementFromRef<S>whereSis the Axum state type.